@@ -28,10 +28,9 @@
 #include <gconf/gconf-client.h>
 
 #include <glib/gi18n-lib.h>
-#include <eog/eog-scroll-view.h>
 #include <eog/eog-image.h>
 #include <eog/eog-thumb-view.h>
-#include <eog/eog-exif-details.h>
+#include <eog/eog-job-queue.h>
 #include <eog/eog-exif-util.h>
 #include <eog/eog-sidebar.h>
 
@@ -181,7 +180,7 @@ static void set_exif_label (ExifData *exif_data, int exif_tag,
 static gchar*
 eog_exif_get_focal_length_desc (ExifData *exif_data)
 {
-	ExifEntry *entry,*entry35mm;
+	ExifEntry *entry = NULL, *entry35mm = NULL;
 	ExifByteOrder byte_order;
 	gfloat f_val = 0.0;
 	gchar *fl_text = NULL,*fl35_text = NULL;
@@ -256,16 +255,12 @@ static void manage_exif_data (WindowData *data)
 {
 	EogImage *image;
 	ExifData *exif_data;
-	ExifEntry *exif_entry;
-	ExifByteOrder byte_order;
 
 	image = eog_thumb_view_get_first_selected_image (data->eog_thumb_view);
 	g_return_if_fail (image != NULL);
 
 	exif_data = (ExifData *)eog_image_get_exif_info (image);
 
-	byte_order = exif_data_get_byte_order (exif_data);
-
 	set_exif_label (exif_data, EXIF_TAG_DATE_TIME_ORIGINAL, data->sidebar_builder, "takenon_label", TRUE);
 
 	eog_exif_set_focal_length_label (GTK_WIDGET (gtk_builder_get_object (
@@ -311,7 +306,7 @@ static void manage_exif_data_cb (EogJob *job, gpointer data)
 static gboolean
 calculate_histogram (WindowData *data, EogImage *eog_image)
 {
-	int rowstride, n_channels;
+	int rowstride;
 	int width, height;
 	int row, col;
 	GdkPixbuf *image_pixbuf;
@@ -441,7 +436,6 @@ static void
 drawing_area_expose (GtkDrawingArea *drawing_area, GdkEventExpose *event,
 	WindowData *data)
 {
-	int i;
 	gboolean draw_channels_histogram, draw_rgb_histogram;
 	EogImage *eog_image;
 	cairo_t *cr;
@@ -449,6 +443,9 @@ drawing_area_expose (GtkDrawingArea *drawing_area, GdkEventExpose *event,
 	int scale_factor_y;
 	GtkStyle *gtk_style;
 
+	if (!GTK_WIDGET_REALIZED (GTK_WIDGET (drawing_area)))
+		return;
+
 	draw_channels_histogram = read_gconf_bool_setting (
 			EOG_EXIF_DISPLAY_CONF_UI_DISPLAY_CHANNELS_HISTOGRAM);
 	draw_rgb_histogram = read_gconf_bool_setting (
@@ -693,7 +690,6 @@ impl_activate (EogPlugin *plugin,
 	WindowData *data;
 	GtkWidget *thumbview;
 	GtkWidget *sidebar;
-	GtkWidget *statusbar = eog_window_get_statusbar (window);
 
 	gconf_client = gconf_client_get_default ();
 
